@@ -1,12 +1,14 @@
 package Net::DNS::RR::CERT;
 
 #
-# $Id: CERT.pm 1037 2012-10-24 21:50:15Z willem $
+# $Id: CERT.pm 1188 2014-04-03 18:54:34Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1037 $)[1];
+$VERSION = (qw$LastChangedRevision: 1188 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::CERT - DNS CERT resource record
 =cut
 
 
-use strict;
 use integer;
 
 use MIME::Base64;
@@ -78,7 +79,7 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $base64    = MIME::Base64::encode $self->{certbin};
 	chomp $base64;
 	return "$format $self->{tag} $algorithm $base64" if length($base64) < 40;
-	return "$format $self->{tag} $algorithm(\n$base64 )";
+	return "$format $self->{tag} $algorithm (\n$base64 )";
 }
 
 
@@ -93,47 +94,54 @@ sub parse_rdata {			## populate RR from rdata in argument list
 sub format {
 	my $self = shift;
 
-	return $self->{format} unless @_;
+	return $self->{format} unless scalar @_;
 
-	my $format = shift || '<undef>';
+	my $format = shift;
+	$format = '<undef>' unless defined $format;
 	$format = $formats{$format} || die "Unknown mnemonic: '$format'"
 			if $format =~ /\D/;			# look up mnemonic
 	$self->{format} = $format;
 }
 
+
 sub tag {
 	my $self = shift;
 
-	$self->{tag} = shift if @_;
-	return 0 + ( $self->{tag} || 0 );
+	$self->{tag} = 0 + shift if scalar @_;
+	return $self->{tag} || 0;
 }
 
+
 sub algorithm {
 	my $self = shift;
 
-	return $self->{algorithm} unless @_;
+	return $self->{algorithm} unless scalar @_;
 
-	my $algorithm = shift || '<undef>';
+	my $algorithm = shift;
+	$algorithm = '<undef>' unless defined $algorithm;
 	$algorithm = $algorithms{$algorithm} || die "Unknown mnemonic: '$algorithm'"
 			if $algorithm =~ /\D/;			# look up mnemonic
 	$self->{algorithm} = $algorithm;
 }
 
+
 sub cert {
 	my $self = shift;
 
-	$self->{certbin} = MIME::Base64::decode( join "", @_ ) if @_;
-	return MIME::Base64::encode( $self->certbin, "" ) if defined wantarray;
+	$self->certbin( MIME::Base64::decode( join "", @_ ) ) if scalar @_;
+	return MIME::Base64::encode( $self->certbin(), "" ) if defined wantarray;
 }
 
+
 sub certbin {
 	my $self = shift;
 
-	$self->{certbin} = shift if @_;
+	$self->{certbin} = shift if scalar @_;
 	$self->{certbin} || "";
 }
 
-sub certificate { &certbin; }				## historical
+
+sub certificate { &certbin; }		## historical
 
 1;
 __END__
@@ -167,6 +175,7 @@ Returns the format code for the certificate (in numeric form)
 =head2 tag
 
     $tag = $rr->tag;
+    $rr->tag( $tag );
 
 Returns the key tag for the public key in the certificate
 
@@ -179,12 +188,14 @@ Returns the algorithm used by the certificate (in numeric form).
 =head2 cert
 
     $cert = $rr->cert;
+    $rr->cert( $cert );
 
 Base64 representation of the certificate.
 
 =head2 certbin
 
     $certbin = $rr->certbin;
+    $rr->certbin( $certbin );
 
 Binary representation of the certificate.
 
@@ -193,13 +204,13 @@ Binary representation of the certificate.
 
 Copyright (c)2002 VeriSign, Mike Schiraldi
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 
 =head1 SEE ALSO
 
