@@ -1,22 +1,30 @@
 package Net::DNS::Resolver::UNIX;
+
 #
-# $Id: UNIX.pm 979 2012-01-27 08:43:38Z willem $
+# $Id: UNIX.pm 1185 2014-04-03 09:21:21Z willem $
 #
+use vars qw($VERSION);
+$VERSION = (qw$LastChangedRevision: 1185 $)[1];
+
+
+=head1 NAME
+
+Net::DNS::Resolver::UNIX - UNIX Resolver Class
+
+=cut
+
 
 use strict;
-use vars qw(@ISA $VERSION);
+use base qw(Net::DNS::Resolver::Base);
 
-use Net::DNS::Resolver::Base ();
 
-@ISA     = qw(Net::DNS::Resolver::Base);
-$VERSION = (qw$LastChangedRevision: 979 $)[1];
-
-my $resolv_conf = '/etc/resolv.conf';
-my $dotfile     = '.resolv.conf';
+my $resolv_conf = "/etc/resolv.conf";
+my $dotfile	= '.resolv.conf';
 
 my @config_path;
-push(@config_path, $ENV{'HOME'}) if exists $ENV{'HOME'};
-push(@config_path, '.');
+push( @config_path, $ENV{HOME} ) if exists $ENV{HOME};
+push( @config_path, '.' );
+
 
 sub init {
 	my ($class) = @_;
@@ -32,28 +40,25 @@ sub init {
 
 	my $defaults = $class->defaults;
 
-	if (!$defaults->{'domain'} && @{$defaults->{'searchlist'}}) {
-		$defaults->{'domain'} = $defaults->{'searchlist'}[0];
-	} elsif (!@{$defaults->{'searchlist'}} && $defaults->{'domain'}) {
-		$defaults->{'searchlist'} = [ $defaults->{'domain'} ];
+	if ( !$defaults->{domain} && @{$defaults->{searchlist}} ) {
+		( $defaults->{domain} ) = @{$defaults->{searchlist}};
+	} elsif ( !@{$defaults->{searchlist}} && $defaults->{domain} ) {
+		$defaults->{searchlist} = [$defaults->{domain}];
 	}
 }
 
+
 1;
 __END__
 
 
-=head1 NAME
-
-Net::DNS::Resolver::UNIX - UNIX Resolver Class
-
 =head1 SYNOPSIS
 
- use Net::DNS::Resolver;
+    use Net::DNS::Resolver;
 
 =head1 DESCRIPTION
 
-This class implements the UNIX specific portions of C<Net::DNS::Resolver>.
+This class implements the OS specific portions of C<Net::DNS::Resolver>.
 
 No user serviceable parts inside, see L<Net::DNS::Resolver|Net::DNS::Resolver>
 for all your resolving needs.
@@ -62,13 +67,11 @@ for all your resolving needs.
 
 Copyright (c) 1997-2002 Michael Fuhr.
 
-Portions Copyright (c) 2002-2004 Chris Reinhardt.
-
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<perl(1)>, L<Net::DNS>, L<Net::DNS::Resolver>
+L<perl>, L<Net::DNS>, L<Net::DNS::Resolver>
 
 =cut
